@@ -1,7 +1,6 @@
 use serde::{Deserialize, Serialize};
 
-use crate::convert;
-use crate::val_helpr::ValidationResult;
+use crate::{convert, val_helpr::ValidationResult};
 
 pub mod button;
 pub use button::Contents as Button;
@@ -26,39 +25,43 @@ pub use select::Select;
 #[derive(Clone, Debug, Deserialize, Hash, PartialEq, Serialize)]
 #[serde(tag = "type", rename_all = "snake_case")]
 pub enum BlockElement<'a> {
-    Button(Button),
-    Checkboxes,
-    DatePicker,
-    Image,
-    MultiSelect,
-    OverflowMenu,
-    PlainInput,
-    RadioButtons,
+  Button(Button),
+  Checkboxes,
+  DatePicker,
+  Image,
+  MultiSelect,
+  OverflowMenu,
+  PlainInput,
+  RadioButtons,
 
-    #[serde(rename = "channels_select")]
-    SelectPublicChannel(select::PublicChannel<'a>),
+  #[serde(rename = "channels_select")]
+  SelectPublicChannel(select::PublicChannel<'a>),
 
-    #[serde(rename = "conversations_select")]
-    SelectConversation(select::Conversation<'a>),
+  #[serde(rename = "conversations_select")]
+  SelectConversation(select::Conversation<'a>),
 
-    #[serde(rename = "users_select")]
-    SelectUser(select::User<'a>),
+  #[serde(rename = "users_select")]
+  SelectUser(select::User<'a>),
 
-    #[serde(rename = "external_select")]
-    SelectExternal(select::External<'a>),
+  #[serde(rename = "external_select")]
+  SelectExternal(select::External<'a>),
+
+  #[serde(rename = "static_select")]
+  SelectStatic(select::Static<'a>),
 }
 
 impl<'a> BlockElement<'a> {
-    pub fn validate(&self) -> ValidationResult {
-        match self {
-            Self::Button(cts) => cts.validate(),
-            Self::SelectPublicChannel(cts) => cts.validate(),
-            Self::SelectConversation(cts) => cts.validate(),
-            Self::SelectUser(cts) => cts.validate(),
-            Self::SelectExternal(cts) => cts.validate(),
-            rest => todo!("validation not implemented for {:?}", rest),
-        }
+  pub fn validate(&self) -> ValidationResult {
+    match self {
+      | Self::Button(cts) => cts.validate(),
+      | Self::SelectPublicChannel(cts) => cts.validate(),
+      | Self::SelectConversation(cts) => cts.validate(),
+      | Self::SelectUser(cts) => cts.validate(),
+      | Self::SelectExternal(cts) => cts.validate(),
+      | Self::SelectStatic(cts) => cts.validate(),
+      | rest => todo!("validation not implemented for {:?}", rest),
     }
+  }
 }
 
 convert!(impl From<Button> for BlockElement<'static> => |b| BlockElement::Button(b));
@@ -69,10 +72,11 @@ convert!(impl<'a> From<Select<'a>> for BlockElement<'a>
         Select::Conversation(s) => s.into(),
         Select::User(s) => s.into(),
         Select::External(s) => s.into(),
-        _ => todo!()
+        Select::Static(s) => s.into(),
     }
 );
 
+convert!(impl<'a> From<select::Static<'a>> for BlockElement<'a> => |s| BlockElement::SelectStatic(s));
 convert!(impl<'a> From<select::External<'a>> for BlockElement<'a> => |s| BlockElement::SelectExternal(s));
 convert!(impl<'a> From<select::PublicChannel<'a>> for BlockElement<'a> => |s| BlockElement::SelectPublicChannel(s));
 convert!(impl<'a> From<select::Conversation<'a>> for BlockElement<'a> => |s| BlockElement::SelectConversation(s));
